@@ -4,7 +4,7 @@ from functools import partial
 import copy
 import logging
 import typing
-from typing import Union, Optional
+from typing import Union, Optional, Dict
 
 import shortuuid
 import aio_pika
@@ -345,11 +345,45 @@ class RmqCommunicator:
     def __str__(self):
         return f'RMQCommunicator({self._connection})'
 
+    @property
+    def server_properties(self) -> Dict:
+        """
+        A dictionary containing server properties as returned by the RMQ server at connection time.
+
+        The details are defined by the RMQ standard and can be found here:
+
+        https://www.rabbitmq.com/amqp-0-9-1-reference.html#connection.start.server-properties
+
+        The protocol states that this dictionary SHOULD contain at least:
+            'host'          - specifying the server host name or address
+            'product'       - giving the name of the server product
+            'version'       - giving the name of the server version
+            'platform'      - giving the name of the operating system
+            'copyright'     - if appropriate, and,
+            'information'   - giving other general information
+
+        .. note:: In testing it seems like 'host' is not always returned.  Host information may be found in
+            'cluster_name' but clients shouldn't rely on this.
+
+        :return: the server properties dictionary
+        """
+        if self._connection is None:
+            return {}
+
+        return self._connection.connection.server_properties
+
     @property
     def loop(self):
         """Get the event loop instance driving this communicator connection."""
         return self._connection.loop
 
+    def add_close_callback(self, callback: aio_pika.types.CloseCallbackType, weak: bool = False) -> None:
+        """Add a callable to be called each time (after) the connection is closed.
+
+        :param weak: If True, the callback will be added to a `WeakSet`
+        """
+        self._connection.add_close_callback(callback, weak)
+
     async def get_default_task_queue(self) -> tasks.RmqTaskQueue:
         """Get a default task queue.
 
@@ -541,7 +575,7 @@ async def async_connect(
     task_prefetch_count=defaults.TASK_PREFETCH_COUNT,
     encoder=defaults.ENCODER,
     decoder=defaults.DECODER,
-    testing_mode=False
+    testing_mode=False,
 ) -> RmqCommunicator:
     # pylint: disable=too-many-arguments
     """Convenience method that returns a connected communicator.
