@@ -5,7 +5,7 @@ import concurrent.futures
 from concurrent.futures import Future as ThreadFuture
 import functools
 import logging
-from typing import Union
+from typing import Union, Dict
 
 import aio_pika
 import deprecation
@@ -45,7 +45,7 @@ class RmqThreadCommunicator(kiwipy.Communicator):
         encoder=defaults.ENCODER,
         decoder=defaults.DECODER,
         testing_mode=False,
-        async_task_timeout=TASK_TIMEOUT
+        async_task_timeout=TASK_TIMEOUT,
     ):
         # pylint: disable=too-many-arguments
         comm = cls(
@@ -78,7 +78,7 @@ class RmqThreadCommunicator(kiwipy.Communicator):
         encoder=defaults.ENCODER,
         decoder=defaults.DECODER,
         testing_mode=False,
-        async_task_timeout=TASK_TIMEOUT
+        async_task_timeout=TASK_TIMEOUT,
     ):
         # pylint: disable=too-many-arguments
         """
@@ -105,11 +105,10 @@ class RmqThreadCommunicator(kiwipy.Communicator):
         self._loop_scheduler.start()  # Star the loop scheduler (i.e. the event loop thread)
 
         # Establish the connection and get a communicator running on our thread
-        self._communicator = self._loop_scheduler.await_(
+        self._communicator: communicator.RmqCommunicator = self._loop_scheduler.await_(
             communicator.async_connect(
                 connection_params=connection_params,
                 connection_factory=connection_factory,
-
                 # Messages
                 message_exchange=message_exchange,
                 queue_expires=queue_expires,
@@ -149,6 +148,30 @@ class RmqThreadCommunicator(kiwipy.Communicator):
     def stop(self):
         self.close()
 
+    @property
+    def server_properties(self) -> Dict:
+        """
+        A dictionary containing server properties as returned by the RMQ server at connection time.
+
+        The details are defined by the RMQ standard and can be found here:
+
+        https://www.rabbitmq.com/amqp-0-9-1-reference.html#connection.start.server-properties
+
+        The protocol states that this dictionary SHOULD contain at least:
+            'host'          - specifying the server host name or address
+            'product'       - giving the name of the server product
+            'version'       - giving the name of the server version
+            'platform'      - giving the name of the operating system
+            'copyright'     - if appropriate, and,
+            'information'   - giving other general information
+
+        .. note:: In testing it seems like 'host' is not always returned.  Host information may be found in
+            'cluster_name' but clients shouldn't rely on this.
+
+        :return: the server properties dictionary
+        """
+        return self._communicator.server_properties
+
     def __enter__(self):
         return self
 
@@ -179,6 +202,14 @@ class RmqThreadCommunicator(kiwipy.Communicator):
         del self._loop
         self._closed = True
 
+    def add_close_callback(self, callback: aio_pika.types.CloseCallbackType, weak: bool = False) -> None:
+        """Add a callable to be called each time (after) the connection is closed.
+
+        :param weak: If True, the callback will be added to a `WeakSet`
+        """
+        self._ensure_open()
+        self._communicator.add_close_callback(callback, weak)
+
     def add_rpc_subscriber(self, subscriber, identifier=None):
         self._ensure_open()
         return self._loop_scheduler.await_(
@@ -339,13 +370,13 @@ def connect(
     task_prefetch_count=defaults.TASK_PREFETCH_COUNT,
     encoder=defaults.ENCODER,
     decoder=defaults.DECODER,
-    testing_mode=False
+    testing_mode=False,
 ) -> RmqThreadCommunicator:
     """
     Establish a RabbitMQ communicator connection
     """
     # pylint: disable=too-many-arguments
-    return RmqThreadCommunicator.connect(
+    _communicator = RmqThreadCommunicator.connect(
         connection_params=connection_params,
         connection_factory=connection_factory,
         message_exchange=message_exchange,
@@ -357,3 +388,4 @@ def connect(
         decoder=decoder,
         testing_mode=testing_mode
     )
+    return _communicator
